module OmniAuth
  module Azure
    module Activedirectory
      module V2
        VERSION = "2.4.0"
        DATE    = "2024-10-17"
      end
    end
  end
end
